@@ -3,9 +3,10 @@ from collections.abc import AsyncGenerator, Awaitable, Coroutine
 from typing import Any, Callable, Generic, Optional, Union, overload, runtime_checkable
 
 from PIL import Image
-from reactivex import Observable
 from typing_extensions import Literal, NotRequired, Protocol, TypedDict, TypeVar
 
+from .hybrid_observer import HybridObservable
+
 # Basic types
 Callback = Union[
     Callable[..., Any],
@@ -113,7 +114,7 @@ DecoderFormat = Literal["yuv", "rgb"]
 ImageInputFormat = Literal["yuv", "rgb", "rgba", "gray"]
 ImageOutputFormat = Literal["rgb", "rgba", "gray"]
 CameraExtension = Literal["hub", "prebuffer", "motionDetection", "objectDetection", "audioDetection", "ptz"]
-CameraFrameWorkerDecoder = Literal["pillow", "wasm"]
+CameraFrameWorkerDecoder = Literal["pillow", "wasm", "rust"]
 CameraFrameWorkerResolution = Literal[
     "3840x2160",
     "3072x1728",
@@ -448,7 +449,7 @@ class ImageCrop(TypedDict):
     height: int
 
 
-class ImageResize(TypedDict, total=False):
+class ImageResize(TypedDict):
     width: int
     height: int
 
@@ -739,52 +740,52 @@ class CameraDevice(Protocol):
     @property
     def internal_sources(self) -> list[CameraDeviceInternalSource]: ...
 
-    on_connected: Observable[bool]
-    on_light_switched: Observable[LightState]
-    on_motion_detected: Observable[MotionState]
-    on_audio_detected: Observable[AudioState]
-    on_object_detected: Observable[ObjectState]
-    on_doorbell_pressed: Observable[DoorbellState]
-    on_siren_detected: Observable[SirenState]
-    on_battery_changed: Observable[BatteryState]
+    on_connected: HybridObservable[bool]
+    on_light_switched: HybridObservable[LightState]
+    on_motion_detected: HybridObservable[MotionState]
+    on_audio_detected: HybridObservable[AudioState]
+    on_object_detected: HybridObservable[ObjectState]
+    on_doorbell_pressed: HybridObservable[DoorbellState]
+    on_siren_detected: HybridObservable[SirenState]
+    on_battery_changed: HybridObservable[BatteryState]
 
     async def snapshot(self, force_new: Optional[bool] = None) -> Optional[bytes]: ...
 
     @overload
     def on_state_change(
         self, state_name: Literal["light"]
-    ) -> Observable[CameraStateChangedObject[LightState]]: ...
+    ) -> HybridObservable[CameraStateChangedObject[LightState]]: ...
     @overload
     def on_state_change(
         self, state_name: Literal["motion"]
-    ) -> Observable[CameraStateChangedObject[MotionState]]: ...
+    ) -> HybridObservable[CameraStateChangedObject[MotionState]]: ...
     @overload
     def on_state_change(
         self, state_name: Literal["audio"]
-    ) -> Observable[CameraStateChangedObject[AudioState]]: ...
+    ) -> HybridObservable[CameraStateChangedObject[AudioState]]: ...
     @overload
     def on_state_change(
         self, state_name: Literal["doorbell"]
-    ) -> Observable[CameraStateChangedObject[DoorbellState]]: ...
+    ) -> HybridObservable[CameraStateChangedObject[DoorbellState]]: ...
     @overload
     def on_state_change(
         self, state_name: Literal["siren"]
-    ) -> Observable[CameraStateChangedObject[SirenState]]: ...
+    ) -> HybridObservable[CameraStateChangedObject[SirenState]]: ...
     @overload
     def on_state_change(
         self, state_name: Literal["battery"]
-    ) -> Observable[CameraStateChangedObject[BatteryState]]: ...
+    ) -> HybridObservable[CameraStateChangedObject[BatteryState]]: ...
     @overload
     def on_state_change(
         self, state_name: Literal["object"]
-    ) -> Observable[CameraStateChangedObject[ObjectState]]: ...
+    ) -> HybridObservable[CameraStateChangedObject[ObjectState]]: ...
     def on_state_change(  # type: ignore
         self, state_name: StateNames
-    ) -> Observable[CameraStateChangedObject[StateValue]]: ...
+    ) -> HybridObservable[CameraStateChangedObject[StateValue]]: ...
 
     def on_property_change(
         self, property: Union[CameraPublicProperties, list[CameraPublicProperties]]
-    ) -> Observable[CameraPropertyObservableObject]: ...
+    ) -> HybridObservable[CameraPropertyObservableObject]: ...
 
     @overload
     def get_value(self, state_name: Literal["light"]) -> LightState: ...
